==> digikam-4.0.0-beta3.tar.bz2: digikam-4.0.0-beta3/extra/kipi-plugins/dropbox/kipiplugin_dropbox.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Dropbox Export
Name=Dropbox Export
Name[bs]=Dropbox Izvoz
Name[ca]=Exportador a Dropbox
Name[cs]=Export do Dropboxu
Name[da]=Eksport til Dropbox
Name[de]=Dropbox-Export
Name[el]=Εξαγωγή στο Dropbox
Name[es]=Exportar a Dropbox
Name[gl]=Exportación a Dropbox
Name[hu]=Dropbox exportálás
Name[it]=Esportazione a Dropbox
Name[nb]=Dropbox eksport
Name[nl]=Exporteren naar Dropbox
Name[pt]=Exportação para o Dropbox
Name[pt_BR]=Exportar para o Dropbox
Name[sk]=Dropbox Export
Name[sl]=Izvoz v Dropbox
Name[sv]=Export till Dropbox
Name[tr]=Dropbox Aktarımı
Name[uk]=Експорт до Dropbox
Name[x-test]=xxDropbox Exportxx
Comment=A tool to export images to a remote Dropbox web service
Comment[bs]=Alat za izvoz slika na udaljeni Dropbox web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Dropbox
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Dropbox
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Dropbox-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Dropbox-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού του Dropbox
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Dropbox
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Dropbox remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Dropbox webszolgáltatásba
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Dropbox
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Dropbox-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Dropbox-webservice te exporteren
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Dropbox
Comment[pt_BR]=Uma ferramenta para exportar imagens para um serviço remoto da Internet Dropbox
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Dropbox
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Dropbox
Comment[sv]=Ett verktyg för att exportera bilder till en Dropbox fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Dropbox web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Dropbox
Comment[x-test]=xxA tool to export images to a remote Dropbox web servicexx
Type=Service
Icon=kipi-dropbox
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dropbox
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Saurabh Patel, saurabhpatel7717@gmail.com

==> digikam-5.0.0-beta3.tar.bz2: digikam-5.0.0-beta3/extra/kipi-plugins/dropbox/kipiplugin_dropbox.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Dropbox Export
Name=Dropbox Export
Name[bs]=Dropbox Izvoz
Name[ca]=Exportador a Dropbox
Name[ca@valencia]=Exportador a Dropbox
Name[cs]=Export do Dropboxu
Name[da]=Eksport til Dropbox
Name[de]=Dropbox-Export
Name[el]=Εξαγωγή στο Dropbox
Name[en_GB]=Dropbox Export
Name[es]=Exportar a Dropbox
Name[fi]=Dropbox-vienti
Name[fr]=Export vers Dropbox
Name[gl]=Exportación a Dropbox
Name[hu]=Dropbox exportálás
Name[is]=Dropbox útflutningur
Name[it]=Esportazione a Dropbox
Name[ko]=Dropbox 내보내기
Name[nb]=Dropbox eksport
Name[nl]=Exporteren naar Dropbox
Name[pl]=Eksportuj do Dropboksa
Name[pt]=Exportação para o Dropbox
Name[pt_BR]=Exportar para o Dropbox
Name[ru]=Экспорт в Dropbox
Name[sk]=Dropbox Export
Name[sl]=Izvoz v Dropbox
Name[sv]=Export till Dropbox
Name[tr]=Dropbox Aktarımı
Name[uk]=Експорт до Dropbox
Name[x-test]=xxDropbox Exportxx
Name[zh_TW]=Dropbox 匯出
Comment=A tool to export images to a remote Dropbox web service
Comment[bs]=Alat za izvoz slika na udaljeni Dropbox web servis
Comment[ca]=Una eina per exportar imatges al servei web remot Dropbox
Comment[ca@valencia]=Una eina per exportar imatges al servei web remot Dropbox
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Dropbox
Comment[da]=Et værktøj til at eksportere billeder til en ekstern Dropbox-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zu einem entfernten Dropbox-Webdienst zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη υπηρεσία ιστού του Dropbox
Comment[en_GB]=A tool to export images to a remote Dropbox web service
Comment[es]=Una herramienta para exportar imágenes al servicio web remoto de Dropbox
Comment[fi]=Kuvien vienti Dropbox-verkkopalveluun
Comment[fr]=Un outil d'export d'images vers le service en ligne « Dropbox »
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web Dropbox remoto
Comment[hu]=Egy eszköz képek exportálásához egy távoli Dropbox webszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á fjartengda Dropbox vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio Web remoto Dropbox
Comment[ko]=원격 Dropbox 웹 서비스로 사진을 내보내는 도구
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Dropbox-nettjeneste
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Dropbox-webservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej Dropboksa
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto Dropbox
Comment[pt_BR]=Ferramenta para exportar imagens para o Dropbox
Comment[ru]=Инструмент для экспорта изображений в сетевое хранилище данных Dropbox
Comment[sk]=Nástroj na export obrázkov na vzdialenú službu Dropbox
Comment[sl]=Orodje za izvoz slik v oddaljeno spletno storitev Dropbox
Comment[sv]=Ett verktyg för att exportera bilder till en Dropbox fjärrwebbtjänst
Comment[tr]=Resimleri uzak bir Dropbox web hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Dropbox
Comment[x-test]=xxA tool to export images to a remote Dropbox web servicexx
Comment[zh_TW]=匯出影像到遠端 Dropbox 網頁服務的工具
Type=Service
Icon=kipi-dropbox
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dropbox
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_LIB_SO_CUR_VERSION}
author=Saurabh Patel, saurabhpatel7717 at gmail dot com
